@@ -26,9 +26,10 @@
 #include <QDebug>
 #include <KDesktopFile>
 #include <KGlobal>
-#include <KStandardDirs>
+
 
 #include <QStandardPaths>
+#include <KSharedConfig>
 
 
 GlobalSettingsWidget::GlobalSettingsWidget( QWidget *parent )
@@ -37,7 +38,7 @@ GlobalSettingsWidget::GlobalSettingsWidget( QWidget *parent )
     {
     ui.setupUi(this);
 
-    QString path = KGlobal::dirs()->findResource( "services", "kded/khotkeys.desktop");
+    QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kde5/services/kded/khotkeys.desktop");
     if ( KDesktopFile::isDesktopFile(path) )
         {
         _config = KSharedConfig::openConfig(
